/**
 * @name exports
 * @static
 * @summary Arguments for the documentreference query
 */
module.exports = {
	authenticator: {
		type: 'reference',
		fhirtype: 'reference',
		xpath: 'DocumentReference.authenticator',
		definition: 'http://hl7.org/fhir/SearchParameter/DocumentReference-authenticator',
		description: 'Who/what authenticated the document',
	},
	author: {
		type: 'reference',
		fhirtype: 'reference',
		xpath: 'DocumentReference.author',
		definition: 'http://hl7.org/fhir/SearchParameter/DocumentReference-author',
		description: 'Who and/or what authored the document',
	},
	class: {
		type: 'token',
		fhirtype: 'token',
		xpath: 'DocumentReference.class',
		definition: 'http://hl7.org/fhir/SearchParameter/DocumentReference-class',
		description: 'Categorization of document',
	},
	created: {
		type: 'date',
		fhirtype: 'date',
		xpath: 'DocumentReference.created',
		definition: 'http://hl7.org/fhir/SearchParameter/DocumentReference-created',
		description: 'Document creation time',
	},
	custodian: {
		type: 'reference',
		fhirtype: 'reference',
		xpath: 'DocumentReference.custodian',
		definition: 'http://hl7.org/fhir/SearchParameter/DocumentReference-custodian',
		description: 'Organization which maintains the document',
	},
	description: {
		type: 'string',
		fhirtype: 'string',
		xpath: 'DocumentReference.description',
		definition: 'http://hl7.org/fhir/SearchParameter/DocumentReference-description',
		description: 'Human-readable description (title)',
	},
	encounter: {
		type: 'reference',
		fhirtype: 'reference',
		xpath: 'DocumentReference.context.encounter',
		definition: 'http://hl7.org/fhir/SearchParameter/DocumentReference-encounter',
		description: 'Context of the document  content',
	},
	event: {
		type: 'token',
		fhirtype: 'token',
		xpath: 'DocumentReference.context.event',
		definition: 'http://hl7.org/fhir/SearchParameter/DocumentReference-event',
		description: 'Main Clinical Acts Documented',
	},
	facility: {
		type: 'token',
		fhirtype: 'token',
		xpath: 'DocumentReference.context.facilityType',
		definition: 'http://hl7.org/fhir/SearchParameter/DocumentReference-facility',
		description: 'Kind of facility where patient was seen',
	},
	format: {
		type: 'token',
		fhirtype: 'token',
		xpath: 'DocumentReference.content.format',
		definition: 'http://hl7.org/fhir/SearchParameter/DocumentReference-format',
		description: 'Format/content rules for the document',
	},
	identifier: {
		type: 'token',
		fhirtype: 'token',
		xpath: 'DocumentReference.masterIdentifier',
		definition: 'http://hl7.org/fhir/SearchParameter/DocumentReference-identifier',
		description: 'Master Version Specific Identifier',
	},
	indexed: {
		type: 'date',
		fhirtype: 'date',
		xpath: 'DocumentReference.indexed',
		definition: 'http://hl7.org/fhir/SearchParameter/DocumentReference-indexed',
		description: 'When this document reference created',
	},
	language: {
		type: 'token',
		fhirtype: 'token',
		xpath: 'DocumentReference.content.attachment.language',
		definition: 'http://hl7.org/fhir/SearchParameter/DocumentReference-language',
		description: 'Human language of the content (BCP-47)',
	},
	location: {
		type: 'uri',
		fhirtype: 'uri',
		xpath: 'DocumentReference.content.attachment.url',
		definition: 'http://hl7.org/fhir/SearchParameter/DocumentReference-location',
		description: 'Uri where the data can be found',
	},
	patient: {
		type: 'reference',
		fhirtype: 'reference',
		xpath: 'DocumentReference.subject',
		definition: 'http://hl7.org/fhir/SearchParameter/DocumentReference-patient',
		description: 'Who/what is the subject of the document',
	},
	period: {
		type: 'date',
		fhirtype: 'date',
		xpath: 'DocumentReference.context.period',
		definition: 'http://hl7.org/fhir/SearchParameter/DocumentReference-period',
		description: 'Time of service that is being documented',
	},
	'related-id': {
		type: 'token',
		fhirtype: 'token',
		xpath: 'DocumentReference.context.related.identifier',
		definition: 'http://hl7.org/fhir/SearchParameter/DocumentReference-related-id',
		description: 'Identifier of related objects or events',
	},
	'related-ref': {
		type: 'reference',
		fhirtype: 'reference',
		xpath: 'DocumentReference.context.related.ref',
		definition: 'http://hl7.org/fhir/SearchParameter/DocumentReference-related-ref',
		description: 'Related Resource',
	},
	relatesto: {
		type: 'reference',
		fhirtype: 'reference',
		xpath: 'DocumentReference.relatesTo.target',
		definition: 'http://hl7.org/fhir/SearchParameter/DocumentReference-relatesto',
		description: 'Target of the relationship',
	},
	relation: {
		type: 'token',
		fhirtype: 'token',
		xpath: 'DocumentReference.relatesTo.code',
		definition: 'http://hl7.org/fhir/SearchParameter/DocumentReference-relation',
		description: 'replaces | transforms | signs | appends',
	},
	relationship: {
		type: 'composite',
		fhirtype: 'composite',
		xpath: '',
		definition: 'http://hl7.org/fhir/SearchParameter/DocumentReference-relationship',
		description: 'Combination of relation and relatesTo',
	},
	securitylabel: {
		type: 'token',
		fhirtype: 'token',
		xpath: 'DocumentReference.securityLabel',
		definition: 'http://hl7.org/fhir/SearchParameter/DocumentReference-securitylabel',
		description: 'Document security-tags',
	},
	setting: {
		type: 'token',
		fhirtype: 'token',
		xpath: 'DocumentReference.context.practiceSetting',
		definition: 'http://hl7.org/fhir/SearchParameter/DocumentReference-setting',
		description: 'Additional details about where the content was created (e.g. clinical specialty)',
	},
	status: {
		type: 'token',
		fhirtype: 'token',
		xpath: 'DocumentReference.status',
		definition: 'http://hl7.org/fhir/SearchParameter/DocumentReference-status',
		description: 'current | superseded | entered-in-error',
	},
	subject: {
		type: 'reference',
		fhirtype: 'reference',
		xpath: 'DocumentReference.subject',
		definition: 'http://hl7.org/fhir/SearchParameter/DocumentReference-subject',
		description: 'Who/what is the subject of the document',
	},
	type: {
		type: 'token',
		fhirtype: 'token',
		xpath: 'DocumentReference.type',
		definition: 'http://hl7.org/fhir/SearchParameter/DocumentReference-type',
		description: 'Kind of document (LOINC if possible)',
	},
};
