/**
 * @name exports
 * @static
 * @summary Arguments for the encounter query
 */
module.exports = {
	appointment: {
		type: 'reference',
		fhirtype: 'reference',
		xpath: 'Encounter.appointment',
		definition: 'http://hl7.org/fhir/SearchParameter/Encounter-appointment',
		description: 'The appointment that scheduled this encounter',
	},
	condition: {
		type: 'reference',
		fhirtype: 'reference',
		xpath: 'Encounter.indication',
		definition: 'http://hl7.org/fhir/SearchParameter/Encounter-condition',
		description: 'Reason the encounter takes place (resource)',
	},
	date: {
		type: 'date',
		fhirtype: 'date',
		xpath: 'Encounter.period',
		definition: 'http://hl7.org/fhir/SearchParameter/Encounter-date',
		description: 'A date within the period the Encounter lasted',
	},
	episodeofcare: {
		type: 'reference',
		fhirtype: 'reference',
		xpath: 'Encounter.episodeOfCare',
		definition: 'http://hl7.org/fhir/SearchParameter/Encounter-episodeofcare',
		description: 'Episode(s) of care that this encounter should be recorded against',
	},
	identifier: {
		type: 'token',
		fhirtype: 'token',
		xpath: 'Encounter.identifier',
		definition: 'http://hl7.org/fhir/SearchParameter/Encounter-identifier',
		description: 'Identifier(s) by which this encounter is known',
	},
	incomingreferral: {
		type: 'reference',
		fhirtype: 'reference',
		xpath: 'Encounter.incomingReferral',
		definition: 'http://hl7.org/fhir/SearchParameter/Encounter-incomingreferral',
		description: 'The ReferralRequest that initiated this encounter',
	},
	indication: {
		type: 'reference',
		fhirtype: 'reference',
		xpath: 'Encounter.indication',
		definition: 'http://hl7.org/fhir/SearchParameter/Encounter-indication',
		description: 'Reason the encounter takes place (resource)',
	},
	length: {
		type: 'number',
		fhirtype: 'number',
		xpath: 'Encounter.length',
		definition: 'http://hl7.org/fhir/SearchParameter/Encounter-length',
		description: 'Length of encounter in days',
	},
	location: {
		type: 'reference',
		fhirtype: 'reference',
		xpath: 'Encounter.location.location',
		definition: 'http://hl7.org/fhir/SearchParameter/Encounter-location',
		description: 'Location the encounter takes place',
	},
	'location-period': {
		type: 'date',
		fhirtype: 'date',
		xpath: 'Encounter.location.period',
		definition: 'http://hl7.org/fhir/SearchParameter/Encounter-location-period',
		description: 'Time period during which the patient was present at the location',
	},
	'part-of': {
		type: 'reference',
		fhirtype: 'reference',
		xpath: 'Encounter.partOf',
		definition: 'http://hl7.org/fhir/SearchParameter/Encounter-part-of',
		description: 'Another Encounter this encounter is part of',
	},
	participant: {
		type: 'reference',
		fhirtype: 'reference',
		xpath: 'Encounter.participant.individual',
		definition: 'http://hl7.org/fhir/SearchParameter/Encounter-participant',
		description: 'Persons involved in the encounter other than the patient',
	},
	'participant-type': {
		type: 'token',
		fhirtype: 'token',
		xpath: 'Encounter.participant.type',
		definition: 'http://hl7.org/fhir/SearchParameter/Encounter-participant-type',
		description: 'Role of participant in encounter',
	},
	patient: {
		type: 'reference',
		fhirtype: 'reference',
		xpath: 'Encounter.patient',
		definition: 'http://hl7.org/fhir/SearchParameter/Encounter-patient',
		description: 'The patient present at the encounter',
	},
	practitioner: {
		type: 'reference',
		fhirtype: 'reference',
		xpath: 'Encounter.participant.individual',
		definition: 'http://hl7.org/fhir/SearchParameter/Encounter-practitioner',
		description: 'Persons involved in the encounter other than the patient',
	},
	procedure: {
		type: 'reference',
		fhirtype: 'reference',
		xpath: 'Encounter.indication',
		definition: 'http://hl7.org/fhir/SearchParameter/Encounter-procedure',
		description: 'Reason the encounter takes place (resource)',
	},
	reason: {
		type: 'token',
		fhirtype: 'token',
		xpath: 'Encounter.reason',
		definition: 'http://hl7.org/fhir/SearchParameter/Encounter-reason',
		description: 'Reason the encounter takes place (code)',
	},
	'special-arrangement': {
		type: 'token',
		fhirtype: 'token',
		xpath: 'Encounter.hospitalization.specialArrangement',
		definition: 'http://hl7.org/fhir/SearchParameter/Encounter-special-arrangement',
		description: 'Wheelchair, translator, stretcher, etc.',
	},
	status: {
		type: 'token',
		fhirtype: 'token',
		xpath: 'Encounter.status',
		definition: 'http://hl7.org/fhir/SearchParameter/Encounter-status',
		description: 'planned | arrived | in-progress | onleave | finished | cancelled',
	},
	type: {
		type: 'token',
		fhirtype: 'token',
		xpath: 'Encounter.type',
		definition: 'http://hl7.org/fhir/SearchParameter/Encounter-type',
		description: 'Specific type of encounter',
	},
};
