/**
 * @name exports
 * @static
 * @summary Arguments for the patient query
 */
module.exports = {
	active: {
		type: 'token',
		fhirtype: 'token',
		xpath: 'Patient.active',
		definition: 'http://hl7.org/fhir/SearchParameter/Patient-active',
		description: 'Whether the patient record is active',
	},
	address: {
		type: 'string',
		fhirtype: 'string',
		xpath: 'Patient.address',
		definition: 'http://hl7.org/fhir/SearchParameter/Patient-address',
		description: 'An address in any kind of address/part of the patient',
	},
	'address-city': {
		type: 'string',
		fhirtype: 'string',
		xpath: 'Patient.address.city',
		definition: 'http://hl7.org/fhir/SearchParameter/Patient-address-city',
		description: 'A city specified in an address',
	},
	'address-country': {
		type: 'string',
		fhirtype: 'string',
		xpath: 'Patient.address.country',
		definition: 'http://hl7.org/fhir/SearchParameter/Patient-address-country',
		description: 'A country specified in an address',
	},
	'address-postalcode': {
		type: 'string',
		fhirtype: 'string',
		xpath: 'Patient.address.postalCode',
		definition: 'http://hl7.org/fhir/SearchParameter/Patient-address-postalcode',
		description: 'A postalCode specified in an address',
	},
	'address-state': {
		type: 'string',
		fhirtype: 'string',
		xpath: 'Patient.address.state',
		definition: 'http://hl7.org/fhir/SearchParameter/Patient-address-state',
		description: 'A state specified in an address',
	},
	'address-use': {
		type: 'token',
		fhirtype: 'token',
		xpath: 'Patient.address.use',
		definition: 'http://hl7.org/fhir/SearchParameter/Patient-address-use',
		description: 'A use code specified in an address',
	},
	'animal-breed': {
		type: 'token',
		fhirtype: 'token',
		xpath: 'Patient.animal.breed',
		definition: 'http://hl7.org/fhir/SearchParameter/Patient-animal-breed',
		description: 'The breed for animal patients',
	},
	'animal-species': {
		type: 'token',
		fhirtype: 'token',
		xpath: 'Patient.animal.species',
		definition: 'http://hl7.org/fhir/SearchParameter/Patient-animal-species',
		description: 'The species for animal patients',
	},
	birthdate: {
		type: 'date',
		fhirtype: 'date',
		xpath: 'Patient.birthDate',
		definition: 'http://hl7.org/fhir/SearchParameter/Patient-birthdate',
		description: "The patient's date of birth",
	},
	careprovider: {
		type: 'reference',
		fhirtype: 'reference',
		xpath: 'Patient.careProvider',
		definition: 'http://hl7.org/fhir/SearchParameter/Patient-careprovider',
		description:
			"Patient's nominated care provider, could be a care manager, not the organization that manages the record",
	},
	deathdate: {
		type: 'date',
		fhirtype: 'date',
		xpath: 'Patient.deceasedDateTime',
		definition: 'http://hl7.org/fhir/SearchParameter/Patient-deathdate',
		description: 'The date of death has been provided and satisfies this search value',
	},
	deceased: {
		type: 'token',
		fhirtype: 'token',
		xpath: 'Patient.deceasedBoolean',
		definition: 'http://hl7.org/fhir/SearchParameter/Patient-deceased',
		description: 'This patient has been marked as deceased, or as a death date entered',
	},
	email: {
		type: 'token',
		fhirtype: 'token',
		xpath: "Patient.telecom[system/@value='email']",
		definition: 'http://hl7.org/fhir/SearchParameter/Patient-email',
		description: 'A value in an email contact',
	},
	family: {
		type: 'string',
		fhirtype: 'string',
		xpath: 'Patient.name.family',
		definition: 'http://hl7.org/fhir/SearchParameter/Patient-family',
		description: 'A portion of the family name of the patient',
	},
	gender: {
		type: 'token',
		fhirtype: 'token',
		xpath: 'Patient.gender',
		definition: 'http://hl7.org/fhir/SearchParameter/Patient-gender',
		description: 'Gender of the patient',
	},
	given: {
		type: 'string',
		fhirtype: 'string',
		xpath: 'Patient.name.given',
		definition: 'http://hl7.org/fhir/SearchParameter/Patient-given',
		description: 'A portion of the given name of the patient',
	},
	identifier: {
		type: 'token',
		fhirtype: 'token',
		xpath: 'Patient.identifier',
		definition: 'http://hl7.org/fhir/SearchParameter/Patient-identifier',
		description: 'A patient identifier',
	},
	language: {
		type: 'token',
		fhirtype: 'token',
		xpath: 'Patient.communication.language',
		definition: 'http://hl7.org/fhir/SearchParameter/Patient-language',
		description: 'Language code (irrespective of use value)',
	},
	link: {
		type: 'reference',
		fhirtype: 'reference',
		xpath: 'Patient.link.other',
		definition: 'http://hl7.org/fhir/SearchParameter/Patient-link',
		description: 'All patients linked to the given patient',
	},
	name: {
		type: 'string',
		fhirtype: 'string',
		xpath: 'Patient.name',
		definition: 'http://hl7.org/fhir/SearchParameter/Patient-name',
		description: 'A portion of either family or given name of the patient',
	},
	organization: {
		type: 'reference',
		fhirtype: 'reference',
		xpath: 'Patient.managingOrganization',
		definition: 'http://hl7.org/fhir/SearchParameter/Patient-organization',
		description: 'The organization at which this person is a patient',
	},
	phone: {
		type: 'token',
		fhirtype: 'token',
		xpath: "Patient.telecom[system/@value='phone']",
		definition: 'http://hl7.org/fhir/SearchParameter/Patient-phone',
		description: 'A value in a phone contact',
	},
	phonetic: {
		type: 'string',
		fhirtype: 'string',
		xpath: 'Patient.name',
		definition: 'http://hl7.org/fhir/SearchParameter/Patient-phonetic',
		description: 'A portion of either family or given name using some kind of phonetic matching algorithm',
	},
	telecom: {
		type: 'token',
		fhirtype: 'token',
		xpath: 'Patient.telecom',
		definition: 'http://hl7.org/fhir/SearchParameter/Patient-telecom',
		description: 'The value in any kind of telecom details of the patient',
	},
	race: {
		type: 'token',
		fhirtype: 'token',
		xpath: "Patient.extension[@url='http://hl7.org/fhir/StructureDefinition/us-core-race']",
		definition: 'http://hl7.org/fhir/SearchParameter/us-core-Patient-race',
		description: 'Returns patients with a race extension matching the specified code.',
	},
	ethnicity: {
		type: 'token',
		fhirtype: 'token',
		xpath: "Patient.extension[@url='http://hl7.org/fhir/StructureDefinition/us-core-ethnicity']",
		definition: 'http://hl7.org/fhir/SearchParameter/us-core-Patient-ethnicity',
		description: 'Returns patients with an ethnicity extension matching the specified code.',
	},
};
