/**
 * @name exports
 * @static
 * @summary Arguments for the person query
 */
module.exports = {
	address: {
		type: 'string',
		fhirtype: 'string',
		xpath: 'Person.address',
		definition: 'http://hl7.org/fhir/SearchParameter/Person-address',
		description: 'An address in any kind of address/part',
	},
	'address-city': {
		type: 'string',
		fhirtype: 'string',
		xpath: 'Person.address.city',
		definition: 'http://hl7.org/fhir/SearchParameter/Person-address-city',
		description: 'A city specified in an address',
	},
	'address-country': {
		type: 'string',
		fhirtype: 'string',
		xpath: 'Person.address.country',
		definition: 'http://hl7.org/fhir/SearchParameter/Person-address-country',
		description: 'A country specified in an address',
	},
	'address-postalcode': {
		type: 'string',
		fhirtype: 'string',
		xpath: 'Person.address.postalCode',
		definition: 'http://hl7.org/fhir/SearchParameter/Person-address-postalcode',
		description: 'A postal code specified in an address',
	},
	'address-state': {
		type: 'string',
		fhirtype: 'string',
		xpath: 'Person.address.state',
		definition: 'http://hl7.org/fhir/SearchParameter/Person-address-state',
		description: 'A state specified in an address',
	},
	'address-use': {
		type: 'token',
		fhirtype: 'token',
		xpath: 'Person.address.use',
		definition: 'http://hl7.org/fhir/SearchParameter/Person-address-use',
		description: 'A use code specified in an address',
	},
	birthdate: {
		type: 'date',
		fhirtype: 'date',
		xpath: 'Person.birthDate',
		definition: 'http://hl7.org/fhir/SearchParameter/Person-birthdate',
		description: "The person's date of birth",
	},
	email: {
		type: 'token',
		fhirtype: 'token',
		xpath: "Person.telecom[system/@value='email']",
		definition: 'http://hl7.org/fhir/SearchParameter/Person-email',
		description: 'A value in an email contact',
	},
	gender: {
		type: 'token',
		fhirtype: 'token',
		xpath: 'Person.gender',
		definition: 'http://hl7.org/fhir/SearchParameter/Person-gender',
		description: 'The gender of the person',
	},
	identifier: {
		type: 'token',
		fhirtype: 'token',
		xpath: 'Person.identifier',
		definition: 'http://hl7.org/fhir/SearchParameter/Person-identifier',
		description: 'A person Identifier',
	},
	link: {
		type: 'reference',
		fhirtype: 'reference',
		xpath: 'Person.link.target',
		definition: 'http://hl7.org/fhir/SearchParameter/Person-link',
		description: 'Any link has this Patient, Person, RelatedPerson or Practitioner reference',
	},
	name: {
		type: 'string',
		fhirtype: 'string',
		xpath: 'Person.name',
		definition: 'http://hl7.org/fhir/SearchParameter/Person-name',
		description: 'A portion of name in any name part',
	},
	organization: {
		type: 'reference',
		fhirtype: 'reference',
		xpath: 'Person.managingOrganization',
		definition: 'http://hl7.org/fhir/SearchParameter/Person-organization',
		description: 'The organization at which this person record is being managed',
	},
	patient: {
		type: 'reference',
		fhirtype: 'reference',
		xpath: 'Person.link.target',
		definition: 'http://hl7.org/fhir/SearchParameter/Person-patient',
		description: 'The Person links to this Patient',
	},
	phone: {
		type: 'token',
		fhirtype: 'token',
		xpath: "Person.telecom[system/@value='phone']",
		definition: 'http://hl7.org/fhir/SearchParameter/Person-phone',
		description: 'A value in a phone contact',
	},
	phonetic: {
		type: 'string',
		fhirtype: 'string',
		xpath: 'Person.name',
		definition: 'http://hl7.org/fhir/SearchParameter/Person-phonetic',
		description: 'A portion of name using some kind of phonetic matching algorithm',
	},
	practitioner: {
		type: 'reference',
		fhirtype: 'reference',
		xpath: 'Person.link.target',
		definition: 'http://hl7.org/fhir/SearchParameter/Person-practitioner',
		description: 'The Person links to this Practitioner',
	},
	relatedperson: {
		type: 'reference',
		fhirtype: 'reference',
		xpath: 'Person.link.target',
		definition: 'http://hl7.org/fhir/SearchParameter/Person-relatedperson',
		description: 'The Person links to this RelatedPerson',
	},
	telecom: {
		type: 'token',
		fhirtype: 'token',
		xpath: 'Person.telecom',
		definition: 'http://hl7.org/fhir/SearchParameter/Person-telecom',
		description: 'The value in any kind of contact',
	},
};
