/**
 * @name exports
 * @static
 * @summary Arguments for the practitioner query
 */
module.exports = {
	address: {
		type: 'string',
		fhirtype: 'string',
		xpath: 'Practitioner.address',
		definition: 'http://hl7.org/fhir/SearchParameter/Practitioner-address',
		description: 'An address in any kind of address/part',
	},
	'address-city': {
		type: 'string',
		fhirtype: 'string',
		xpath: 'Practitioner.address.city',
		definition: 'http://hl7.org/fhir/SearchParameter/Practitioner-address-city',
		description: 'A city specified in an address',
	},
	'address-country': {
		type: 'string',
		fhirtype: 'string',
		xpath: 'Practitioner.address.country',
		definition: 'http://hl7.org/fhir/SearchParameter/Practitioner-address-country',
		description: 'A country specified in an address',
	},
	'address-postalcode': {
		type: 'string',
		fhirtype: 'string',
		xpath: 'Practitioner.address.postalCode',
		definition: 'http://hl7.org/fhir/SearchParameter/Practitioner-address-postalcode',
		description: 'A postalCode specified in an address',
	},
	'address-state': {
		type: 'string',
		fhirtype: 'string',
		xpath: 'Practitioner.address.state',
		definition: 'http://hl7.org/fhir/SearchParameter/Practitioner-address-state',
		description: 'A state specified in an address',
	},
	'address-use': {
		type: 'token',
		fhirtype: 'token',
		xpath: 'Practitioner.address.use',
		definition: 'http://hl7.org/fhir/SearchParameter/Practitioner-address-use',
		description: 'A use code specified in an address',
	},
	communication: {
		type: 'token',
		fhirtype: 'token',
		xpath: 'Practitioner.communication',
		definition: 'http://hl7.org/fhir/SearchParameter/Practitioner-communication',
		description: 'One of the languages that the practitioner can communicate with',
	},
	email: {
		type: 'token',
		fhirtype: 'token',
		xpath: "Practitioner.telecom[system/@value='email']",
		definition: 'http://hl7.org/fhir/SearchParameter/Practitioner-email',
		description: 'A value in an email contact',
	},
	family: {
		type: 'string',
		fhirtype: 'string',
		xpath: 'Practitioner.name.family',
		definition: 'http://hl7.org/fhir/SearchParameter/Practitioner-family',
		description: 'A portion of the family name',
	},
	gender: {
		type: 'token',
		fhirtype: 'token',
		xpath: 'Practitioner.gender',
		definition: 'http://hl7.org/fhir/SearchParameter/Practitioner-gender',
		description: 'Gender of the practitioner',
	},
	given: {
		type: 'string',
		fhirtype: 'string',
		xpath: 'Practitioner.name.given',
		definition: 'http://hl7.org/fhir/SearchParameter/Practitioner-given',
		description: 'A portion of the given name',
	},
	identifier: {
		type: 'token',
		fhirtype: 'token',
		xpath: 'Practitioner.identifier',
		definition: 'http://hl7.org/fhir/SearchParameter/Practitioner-identifier',
		description: "A practitioner's Identifier",
	},
	location: {
		type: 'reference',
		fhirtype: 'reference',
		xpath: 'Practitioner.practitionerRole.location',
		definition: 'http://hl7.org/fhir/SearchParameter/Practitioner-location',
		description: 'One of the locations at which this practitioner provides care',
	},
	name: {
		type: 'string',
		fhirtype: 'string',
		xpath: 'Practitioner.name',
		definition: 'http://hl7.org/fhir/SearchParameter/Practitioner-name',
		description: 'A portion of either family or given name',
	},
	organization: {
		type: 'reference',
		fhirtype: 'reference',
		xpath: 'Practitioner.practitionerRole.managingOrganization',
		definition: 'http://hl7.org/fhir/SearchParameter/Practitioner-organization',
		description: 'The identity of the organization the practitioner represents / acts on behalf of',
	},
	phone: {
		type: 'token',
		fhirtype: 'token',
		xpath: "Practitioner.telecom[system/@value='phone']",
		definition: 'http://hl7.org/fhir/SearchParameter/Practitioner-phone',
		description: 'A value in a phone contact',
	},
	phonetic: {
		type: 'string',
		fhirtype: 'string',
		xpath: 'Practitioner.name',
		definition: 'http://hl7.org/fhir/SearchParameter/Practitioner-phonetic',
		description: 'A portion of either family or given name using some kind of phonetic matching algorithm',
	},
	role: {
		type: 'token',
		fhirtype: 'token',
		xpath: 'Practitioner.practitionerRole.role',
		definition: 'http://hl7.org/fhir/SearchParameter/Practitioner-role',
		description: 'The practitioner can perform this role at for the organization',
	},
	specialty: {
		type: 'token',
		fhirtype: 'token',
		xpath: 'Practitioner.practitionerRole.specialty',
		definition: 'http://hl7.org/fhir/SearchParameter/Practitioner-specialty',
		description: 'The practitioner has this specialty at an organization',
	},
	telecom: {
		type: 'token',
		fhirtype: 'token',
		xpath: 'Practitioner.telecom',
		definition: 'http://hl7.org/fhir/SearchParameter/Practitioner-telecom',
		description: 'The value in any kind of contact',
	},
};
