/**
 * @name exports
 * @static
 * @summary Arguments for the structuredefinition query
 */
module.exports = {
	abstract: {
		type: 'token',
		fhirtype: 'token',
		xpath: 'StructureDefinition.abstract',
		definition: 'http://hl7.org/fhir/SearchParameter/StructureDefinition-abstract',
		description: 'Whether the structure is abstract',
	},
	base: {
		type: 'uri',
		fhirtype: 'uri',
		xpath: 'StructureDefinition.base',
		definition: 'http://hl7.org/fhir/SearchParameter/StructureDefinition-base',
		description: 'Structure that this set of constraints applies to',
	},
	'base-path': {
		type: 'token',
		fhirtype: 'token',
		xpath: 'StructureDefinition.snapshot.element.base.path',
		definition: 'http://hl7.org/fhir/SearchParameter/StructureDefinition-base-path',
		description: 'Path that identifies the base element',
	},
	code: {
		type: 'token',
		fhirtype: 'token',
		xpath: 'StructureDefinition.code',
		definition: 'http://hl7.org/fhir/SearchParameter/StructureDefinition-code',
		description: 'A code for the profile',
	},
	context: {
		type: 'token',
		fhirtype: 'token',
		xpath: 'StructureDefinition.useContext',
		definition: 'http://hl7.org/fhir/SearchParameter/StructureDefinition-context',
		description: 'A use context assigned to the structure',
	},
	'context-type': {
		type: 'token',
		fhirtype: 'token',
		xpath: 'StructureDefinition.contextType',
		definition: 'http://hl7.org/fhir/SearchParameter/StructureDefinition-context-type',
		description: 'resource | datatype | mapping | extension',
	},
	date: {
		type: 'date',
		fhirtype: 'date',
		xpath: 'StructureDefinition.date',
		definition: 'http://hl7.org/fhir/SearchParameter/StructureDefinition-date',
		description: 'The profile publication date',
	},
	description: {
		type: 'string',
		fhirtype: 'string',
		xpath: 'StructureDefinition.description',
		definition: 'http://hl7.org/fhir/SearchParameter/StructureDefinition-description',
		description: 'Text search in the description of the profile',
	},
	display: {
		type: 'string',
		fhirtype: 'string',
		xpath: 'StructureDefinition.display',
		definition: 'http://hl7.org/fhir/SearchParameter/StructureDefinition-display',
		description: 'Use this name when displaying the value',
	},
	experimental: {
		type: 'token',
		fhirtype: 'token',
		xpath: 'StructureDefinition.experimental',
		definition: 'http://hl7.org/fhir/SearchParameter/StructureDefinition-experimental',
		description: 'If for testing purposes, not real usage',
	},
	'ext-context': {
		type: 'string',
		fhirtype: 'string',
		xpath: 'StructureDefinition.context',
		definition: 'http://hl7.org/fhir/SearchParameter/StructureDefinition-ext-context',
		description: 'Where the extension can be used in instances',
	},
	identifier: {
		type: 'token',
		fhirtype: 'token',
		xpath: 'StructureDefinition.identifier',
		definition: 'http://hl7.org/fhir/SearchParameter/StructureDefinition-identifier',
		description: 'The identifier of the profile',
	},
	kind: {
		type: 'token',
		fhirtype: 'token',
		xpath: 'StructureDefinition.kind',
		definition: 'http://hl7.org/fhir/SearchParameter/StructureDefinition-kind',
		description: 'datatype | resource | logical',
	},
	name: {
		type: 'string',
		fhirtype: 'string',
		xpath: 'StructureDefinition.name',
		definition: 'http://hl7.org/fhir/SearchParameter/StructureDefinition-name',
		description: 'Name of the profile',
	},
	path: {
		type: 'token',
		fhirtype: 'token',
		xpath: 'StructureDefinition.snapshot.element.path',
		definition: 'http://hl7.org/fhir/SearchParameter/StructureDefinition-path',
		description: 'A path that is constrained in the profile',
	},
	publisher: {
		type: 'string',
		fhirtype: 'string',
		xpath: 'StructureDefinition.publisher',
		definition: 'http://hl7.org/fhir/SearchParameter/StructureDefinition-publisher',
		description: 'Name of the publisher of the profile',
	},
	status: {
		type: 'token',
		fhirtype: 'token',
		xpath: 'StructureDefinition.status',
		definition: 'http://hl7.org/fhir/SearchParameter/StructureDefinition-status',
		description: 'The current status of the profile',
	},
	type: {
		type: 'token',
		fhirtype: 'token',
		xpath: 'StructureDefinition.constrainedType',
		definition: 'http://hl7.org/fhir/SearchParameter/StructureDefinition-type',
		description: 'Any datatype or resource, including abstract ones',
	},
	url: {
		type: 'uri',
		fhirtype: 'uri',
		xpath: 'StructureDefinition.url',
		definition: 'http://hl7.org/fhir/SearchParameter/StructureDefinition-url',
		description: 'Absolute URL used to reference this StructureDefinition',
	},
	valueset: {
		type: 'reference',
		fhirtype: 'reference',
		xpath: 'StructureDefinition.snapshot.element.binding.valueSetUri',
		definition: 'http://hl7.org/fhir/SearchParameter/StructureDefinition-valueset',
		description: 'A vocabulary binding reference',
	},
	version: {
		type: 'token',
		fhirtype: 'token',
		xpath: 'StructureDefinition.version',
		definition: 'http://hl7.org/fhir/SearchParameter/StructureDefinition-version',
		description: 'The version identifier of the profile',
	},
};
