/**
 * @name exports
 * @summary ConformanceRestSecurity Class
 */
module.exports = class ConformanceRestSecurity {
	constructor(opts) {
		// Create an object to store all props
		Object.defineProperty(this, '__data', { value: {} });

		// Define getters and setters as enumerable

		Object.defineProperty(this, '_id', {
			enumerable: true,
			get: () => this.__data._id,
			set: value => {
				if (value === undefined || value === null) {
					return;
				}

				let Element = require('./element.js');
				this.__data._id = new Element(value);
			},
		});

		Object.defineProperty(this, 'id', {
			enumerable: true,
			get: () => this.__data.id,
			set: value => {
				if (value === undefined || value === null) {
					return;
				}

				this.__data.id = value;
			},
		});

		Object.defineProperty(this, 'extension', {
			enumerable: true,
			get: () => this.__data.extension,
			set: value => {
				if (value === undefined || value === null) {
					return;
				}

				let Extension = require('./extension.js');
				this.__data.extension = Array.isArray(value) ? value.map(v => new Extension(v)) : [new Extension(value)];
			},
		});

		Object.defineProperty(this, 'modifierExtension', {
			enumerable: true,
			get: () => this.__data.modifierExtension,
			set: value => {
				if (value === undefined || value === null) {
					return;
				}

				let Extension = require('./extension.js');
				this.__data.modifierExtension = Array.isArray(value)
					? value.map(v => new Extension(v))
					: [new Extension(value)];
			},
		});

		Object.defineProperty(this, '_cors', {
			enumerable: true,
			get: () => this.__data._cors,
			set: value => {
				if (value === undefined || value === null) {
					return;
				}

				let Element = require('./element.js');
				this.__data._cors = new Element(value);
			},
		});

		Object.defineProperty(this, 'cors', {
			enumerable: true,
			get: () => this.__data.cors,
			set: value => {
				if (value === undefined || value === null) {
					return;
				}

				this.__data.cors = value;
			},
		});
		// valueSetReference: http://hl7.org/fhir/ValueSet/restful-security-service
		Object.defineProperty(this, 'service', {
			enumerable: true,
			get: () => this.__data.service,
			set: value => {
				if (value === undefined || value === null) {
					return;
				}

				let CodeableConcept = require('./codeableconcept.js');
				this.__data.service = Array.isArray(value)
					? value.map(v => new CodeableConcept(v))
					: [new CodeableConcept(value)];
			},
		});

		Object.defineProperty(this, '_description', {
			enumerable: true,
			get: () => this.__data._description,
			set: value => {
				if (value === undefined || value === null) {
					return;
				}

				let Element = require('./element.js');
				this.__data._description = new Element(value);
			},
		});

		Object.defineProperty(this, 'description', {
			enumerable: true,
			get: () => this.__data.description,
			set: value => {
				if (value === undefined || value === null) {
					return;
				}

				this.__data.description = value;
			},
		});

		Object.defineProperty(this, 'certificate', {
			enumerable: true,
			get: () => this.__data.certificate,
			set: value => {
				if (value === undefined || value === null) {
					return;
				}

				let ConformanceRestSecurityCertificate = require('./conformancerestsecuritycertificate.js');
				this.__data.certificate = Array.isArray(value)
					? value.map(v => new ConformanceRestSecurityCertificate(v))
					: [new ConformanceRestSecurityCertificate(value)];
			},
		});

		// Merge in any defaults
		Object.assign(this, opts);

		// Define a default non-writable resourceType property
		Object.defineProperty(this, 'resourceType', {
			value: 'ConformanceRestSecurity',
			enumerable: true,
			writable: false,
		});
	}

	static get resourceType() {
		return 'ConformanceRestSecurity';
	}

	toJSON() {
		return {
			_id: this._id && this._id.toJSON(),
			id: this.id,
			extension: this.extension && this.extension.map(v => v.toJSON()),
			modifierExtension: this.modifierExtension && this.modifierExtension.map(v => v.toJSON()),
			_cors: this._cors && this._cors.toJSON(),
			cors: this.cors,
			service: this.service && this.service.map(v => v.toJSON()),
			_description: this._description && this._description.toJSON(),
			description: this.description,
			certificate: this.certificate && this.certificate.map(v => v.toJSON()),
		};
	}
};
