/**
 * @name exports
 * @static
 * @summary Arguments for the conceptmap query
 */
module.exports = {
	date: {
		type: 'date',
		fhirtype: 'date',
		xpath: 'ConceptMap.date',
		definition: 'http://hl7.org/fhir/SearchParameter/ConceptMap-date',
		description: 'The concept map publication date',
	},
	dependson: {
		type: 'uri',
		fhirtype: 'uri',
		xpath: 'ConceptMap.group.element.target.dependsOn.property',
		definition: 'http://hl7.org/fhir/SearchParameter/ConceptMap-dependson',
		description: 'Reference to property mapping depends on',
	},
	description: {
		type: 'string',
		fhirtype: 'string',
		xpath: 'ConceptMap.description',
		definition: 'http://hl7.org/fhir/SearchParameter/ConceptMap-description',
		description: 'The description of the concept map',
	},
	identifier: {
		type: 'token',
		fhirtype: 'token',
		xpath: 'ConceptMap.identifier',
		definition: 'http://hl7.org/fhir/SearchParameter/ConceptMap-identifier',
		description: 'External identifier for the concept map',
	},
	jurisdiction: {
		type: 'token',
		fhirtype: 'token',
		xpath: 'ConceptMap.jurisdiction',
		definition: 'http://hl7.org/fhir/SearchParameter/ConceptMap-jurisdiction',
		description: 'Intended jurisdiction for the concept map',
	},
	name: {
		type: 'string',
		fhirtype: 'string',
		xpath: 'ConceptMap.name',
		definition: 'http://hl7.org/fhir/SearchParameter/ConceptMap-name',
		description: 'Computationally friendly name of the concept map',
	},
	other: {
		type: 'uri',
		fhirtype: 'uri',
		xpath: 'ConceptMap.group.unmapped.url',
		definition: 'http://hl7.org/fhir/SearchParameter/ConceptMap-other',
		description: 'Canonical URL for other concept map',
	},
	product: {
		type: 'uri',
		fhirtype: 'uri',
		xpath: 'ConceptMap.group.element.target.product.property',
		definition: 'http://hl7.org/fhir/SearchParameter/ConceptMap-product',
		description: 'Reference to property mapping depends on',
	},
	publisher: {
		type: 'string',
		fhirtype: 'string',
		xpath: 'ConceptMap.publisher',
		definition: 'http://hl7.org/fhir/SearchParameter/ConceptMap-publisher',
		description: 'Name of the publisher of the concept map',
	},
	source: {
		type: 'reference',
		fhirtype: 'reference',
		xpath: 'ConceptMap.sourceReference',
		definition: 'http://hl7.org/fhir/SearchParameter/ConceptMap-source',
		description: 'Identifies the source of the concepts which are being mapped',
	},
	'source-code': {
		type: 'token',
		fhirtype: 'token',
		xpath: 'ConceptMap.group.element.code',
		definition: 'http://hl7.org/fhir/SearchParameter/ConceptMap-source-code',
		description: 'Identifies element being mapped',
	},
	'source-system': {
		type: 'uri',
		fhirtype: 'uri',
		xpath: 'ConceptMap.group.source',
		definition: 'http://hl7.org/fhir/SearchParameter/ConceptMap-source-system',
		description: 'Code System (if value set crosses code systems)',
	},
	'source-uri': {
		type: 'reference',
		fhirtype: 'reference',
		xpath: 'ConceptMap.sourceUri',
		definition: 'http://hl7.org/fhir/SearchParameter/ConceptMap-source-uri',
		description: 'Identifies the source of the concepts which are being mapped',
	},
	status: {
		type: 'token',
		fhirtype: 'token',
		xpath: 'ConceptMap.status',
		definition: 'http://hl7.org/fhir/SearchParameter/ConceptMap-status',
		description: 'The current status of the concept map',
	},
	target: {
		type: 'reference',
		fhirtype: 'reference',
		xpath: 'ConceptMap.targetReference',
		definition: 'http://hl7.org/fhir/SearchParameter/ConceptMap-target',
		description: 'Provides context to the mappings',
	},
	'target-code': {
		type: 'token',
		fhirtype: 'token',
		xpath: 'ConceptMap.group.element.target.code',
		definition: 'http://hl7.org/fhir/SearchParameter/ConceptMap-target-code',
		description: 'Code that identifies the target element',
	},
	'target-system': {
		type: 'uri',
		fhirtype: 'uri',
		xpath: 'ConceptMap.group.target',
		definition: 'http://hl7.org/fhir/SearchParameter/ConceptMap-target-system',
		description: 'System of the target (if necessary)',
	},
	'target-uri': {
		type: 'reference',
		fhirtype: 'reference',
		xpath: 'ConceptMap.targetUri',
		definition: 'http://hl7.org/fhir/SearchParameter/ConceptMap-target-uri',
		description: 'Provides context to the mappings',
	},
	title: {
		type: 'string',
		fhirtype: 'string',
		xpath: 'ConceptMap.title',
		definition: 'http://hl7.org/fhir/SearchParameter/ConceptMap-title',
		description: 'The human-friendly name of the concept map',
	},
	url: {
		type: 'uri',
		fhirtype: 'uri',
		xpath: 'ConceptMap.url',
		definition: 'http://hl7.org/fhir/SearchParameter/ConceptMap-url',
		description: 'The uri that identifies the concept map',
	},
	version: {
		type: 'token',
		fhirtype: 'token',
		xpath: 'ConceptMap.version',
		definition: 'http://hl7.org/fhir/SearchParameter/ConceptMap-version',
		description: 'The business version of the concept map',
	},
};
