/**
 * @name exports
 * @static
 * @summary Arguments for the documentreference query
 */
module.exports = {
	identifier: {
		type: 'token',
		fhirtype: 'token',
		xpath: 'DocumentReference.masterIdentifier',
		definition: 'http://hl7.org/fhir/SearchParameter/clinical-identifier',
		description:
			'Multiple Resources:     * [DocumentManifest](documentmanifest.html): Unique Identifier for the set of documents  * [Goal](goal.html): External Ids for this goal  * [Consent](consent.html): Identifier for this record (external references)  * [DocumentReference](documentreference.html): Master Version Specific Identifier  * [SupplyRequest](supplyrequest.html): Unique identifier  * [RiskAssessment](riskassessment.html): Unique identifier for the assessment  * [CareTeam](careteam.html): External Ids for this team  * [ImagingStudy](imagingstudy.html): Other identifiers for the Study  * [FamilyMemberHistory](familymemberhistory.html): A search by a record identifier  * [Encounter](encounter.html): Identifier(s) by which this encounter is known  * [DeviceRequest](devicerequest.html): Business identifier for request/order  * [AllergyIntolerance](allergyintolerance.html): External ids for this item  * [CarePlan](careplan.html): External Ids for this plan  * [EpisodeOfCare](episodeofcare.html): Business Identifier(s) relevant for this EpisodeOfCare  * [Procedure](procedure.html): A unique identifier for a procedure  * [List](list.html): Business identifier  * [Immunization](immunization.html): Business identifier  * [VisionPrescription](visionprescription.html): Return prescriptions with this external identifier  * [ProcedureRequest](procedurerequest.html): Identifiers assigned to this order  * [Observation](observation.html): The unique id for a particular observation  * [DiagnosticReport](diagnosticreport.html): An identifier for the report  * [NutritionOrder](nutritionorder.html): Return nutrition orders with this external identifier  * [Condition](condition.html): A unique identifier of the condition record  * [Composition](composition.html): Logical identifier of composition (version-independent)  * [DetectedIssue](detectedissue.html): Unique id for the detected issue  * [SupplyDelivery](supplydelivery.html): External identifier  ',
	},
	patient: {
		type: 'reference',
		fhirtype: 'reference',
		xpath: 'DocumentReference.subject',
		definition: 'http://hl7.org/fhir/SearchParameter/clinical-patient',
		description:
			'Multiple Resources:     * [ReferralRequest](referralrequest.html): Who the referral is about  * [DocumentManifest](documentmanifest.html): The subject of the set of documents  * [Goal](goal.html): Who this goal is intended for  * [Consent](consent.html): Who the consent applies to  * [DocumentReference](documentreference.html): Who/what is the subject of the document  * [ImagingManifest](imagingmanifest.html): Subject of the ImagingManifest (or a DICOM Key Object Selection which it represents)  * [RiskAssessment](riskassessment.html): Who/what does assessment apply to?  * [CareTeam](careteam.html): Who care team is for  * [ImagingStudy](imagingstudy.html): Who the study is about  * [FamilyMemberHistory](familymemberhistory.html): The identity of a subject to list family member history items for  * [Encounter](encounter.html): The patient ro group present at the encounter  * [DeviceUseStatement](deviceusestatement.html): Search by subject - a patient  * [DeviceRequest](devicerequest.html): Individual the service is ordered for  * [AllergyIntolerance](allergyintolerance.html): Who the sensitivity is for  * [CarePlan](careplan.html): Who care plan is for  * [EpisodeOfCare](episodeofcare.html): The patient who is the focus of this episode of care  * [Procedure](procedure.html): Search by subject - a patient  * [List](list.html): If all resources have the same subject  * [Immunization](immunization.html): The patient for the vaccination record  * [VisionPrescription](visionprescription.html): The identity of a patient to list dispenses for  * [ProcedureRequest](procedurerequest.html): Search by subject - a patient  * [Flag](flag.html): The identity of a subject to list flags for  * [Observation](observation.html): The subject that the observation is about (if patient)  * [DiagnosticReport](diagnosticreport.html): The subject of the report if a patient  * [NutritionOrder](nutritionorder.html): The identity of the person who requires the diet, formula or nutritional supplement  * [Condition](condition.html): Who has the condition?  * [Composition](composition.html): Who and/or what the composition is about  * [DetectedIssue](detectedissue.html): Associated patient  * [SupplyDelivery](supplydelivery.html): Patient for whom the item is supplied  * [ClinicalImpression](clinicalimpression.html): Patient or group assessed  ',
	},
	type: {
		type: 'token',
		fhirtype: 'token',
		xpath: 'DocumentReference.type',
		definition: 'http://hl7.org/fhir/SearchParameter/clinical-type',
		description:
			'Multiple Resources:     * [ReferralRequest](referralrequest.html): The type of the referral  * [DocumentManifest](documentmanifest.html): Kind of document set  * [DocumentReference](documentreference.html): Kind of document (LOINC if possible)  * [Encounter](encounter.html): Specific type of encounter  * [AllergyIntolerance](allergyintolerance.html): allergy | intolerance - Underlying mechanism (if known)  * [EpisodeOfCare](episodeofcare.html): Type/class  - e.g. specialist referral, disease management  * [Composition](composition.html): Kind of composition (LOINC if possible)  ',
	},
	encounter: {
		type: 'reference',
		fhirtype: 'reference',
		xpath: 'DocumentReference.context.encounter',
		definition: 'http://hl7.org/fhir/SearchParameter/clinical-encounter',
		description:
			'Multiple Resources:     * [DocumentReference](documentreference.html): Context of the document  content  * [RiskAssessment](riskassessment.html): Where was assessment performed?  * [DeviceRequest](devicerequest.html): Encounter or Episode during which request was created  * [Procedure](procedure.html): Search by encounter  * [List](list.html): Context in which list created  * [VisionPrescription](visionprescription.html): Return prescriptions with this encounter identifier  * [ProcedureRequest](procedurerequest.html): An encounter in which this request is made  * [Flag](flag.html): Alert relevant during encounter  * [Observation](observation.html): Encounter related to the observation  * [DiagnosticReport](diagnosticreport.html): The Encounter when the order was made  * [NutritionOrder](nutritionorder.html): Return nutrition orders with this encounter identifier  * [Composition](composition.html): Context of the Composition  ',
	},
	authenticator: {
		type: 'reference',
		fhirtype: 'reference',
		xpath: 'DocumentReference.authenticator',
		definition: 'http://hl7.org/fhir/SearchParameter/DocumentReference-authenticator',
		description: 'Who/what authenticated the document',
	},
	author: {
		type: 'reference',
		fhirtype: 'reference',
		xpath: 'DocumentReference.author',
		definition: 'http://hl7.org/fhir/SearchParameter/DocumentReference-author',
		description: 'Who and/or what authored the document',
	},
	class: {
		type: 'token',
		fhirtype: 'token',
		xpath: 'DocumentReference.class',
		definition: 'http://hl7.org/fhir/SearchParameter/DocumentReference-class',
		description: 'Categorization of document',
	},
	created: {
		type: 'date',
		fhirtype: 'date',
		xpath: 'DocumentReference.created',
		definition: 'http://hl7.org/fhir/SearchParameter/DocumentReference-created',
		description: 'Document creation time',
	},
	custodian: {
		type: 'reference',
		fhirtype: 'reference',
		xpath: 'DocumentReference.custodian',
		definition: 'http://hl7.org/fhir/SearchParameter/DocumentReference-custodian',
		description: 'Organization which maintains the document',
	},
	description: {
		type: 'string',
		fhirtype: 'string',
		xpath: 'DocumentReference.description',
		definition: 'http://hl7.org/fhir/SearchParameter/DocumentReference-description',
		description: 'Human-readable description (title)',
	},
	event: {
		type: 'token',
		fhirtype: 'token',
		xpath: 'DocumentReference.context.event',
		definition: 'http://hl7.org/fhir/SearchParameter/DocumentReference-event',
		description: 'Main clinical acts documented',
	},
	facility: {
		type: 'token',
		fhirtype: 'token',
		xpath: 'DocumentReference.context.facilityType',
		definition: 'http://hl7.org/fhir/SearchParameter/DocumentReference-facility',
		description: 'Kind of facility where patient was seen',
	},
	format: {
		type: 'token',
		fhirtype: 'token',
		xpath: 'DocumentReference.content.format',
		definition: 'http://hl7.org/fhir/SearchParameter/DocumentReference-format',
		description: 'Format/content rules for the document',
	},
	indexed: {
		type: 'date',
		fhirtype: 'date',
		xpath: 'DocumentReference.indexed',
		definition: 'http://hl7.org/fhir/SearchParameter/DocumentReference-indexed',
		description: 'When this document reference was created',
	},
	language: {
		type: 'token',
		fhirtype: 'token',
		xpath: 'DocumentReference.content.attachment.language',
		definition: 'http://hl7.org/fhir/SearchParameter/DocumentReference-language',
		description: 'Human language of the content (BCP-47)',
	},
	location: {
		type: 'uri',
		fhirtype: 'uri',
		xpath: 'DocumentReference.content.attachment.url',
		definition: 'http://hl7.org/fhir/SearchParameter/DocumentReference-location',
		description: 'Uri where the data can be found',
	},
	period: {
		type: 'date',
		fhirtype: 'date',
		xpath: 'DocumentReference.context.period',
		definition: 'http://hl7.org/fhir/SearchParameter/DocumentReference-period',
		description: 'Time of service that is being documented',
	},
	'related-id': {
		type: 'token',
		fhirtype: 'token',
		xpath: 'DocumentReference.context.related.identifier',
		definition: 'http://hl7.org/fhir/SearchParameter/DocumentReference-related-id',
		description: 'Identifier of related objects or events',
	},
	'related-ref': {
		type: 'reference',
		fhirtype: 'reference',
		xpath: 'DocumentReference.context.related.ref',
		definition: 'http://hl7.org/fhir/SearchParameter/DocumentReference-related-ref',
		description: 'Related Resource',
	},
	relatesto: {
		type: 'reference',
		fhirtype: 'reference',
		xpath: 'DocumentReference.relatesTo.target',
		definition: 'http://hl7.org/fhir/SearchParameter/DocumentReference-relatesto',
		description: 'Target of the relationship',
	},
	relation: {
		type: 'token',
		fhirtype: 'token',
		xpath: 'DocumentReference.relatesTo.code',
		definition: 'http://hl7.org/fhir/SearchParameter/DocumentReference-relation',
		description: 'replaces | transforms | signs | appends',
	},
	relationship: {
		type: 'composite',
		fhirtype: 'composite',
		xpath: '',
		definition: 'http://hl7.org/fhir/SearchParameter/DocumentReference-relationship',
		description: 'Combination of relation and relatesTo',
	},
	securitylabel: {
		type: 'token',
		fhirtype: 'token',
		xpath: 'DocumentReference.securityLabel',
		definition: 'http://hl7.org/fhir/SearchParameter/DocumentReference-securitylabel',
		description: 'Document security-tags',
	},
	setting: {
		type: 'token',
		fhirtype: 'token',
		xpath: 'DocumentReference.context.practiceSetting',
		definition: 'http://hl7.org/fhir/SearchParameter/DocumentReference-setting',
		description: 'Additional details about where the content was created (e.g. clinical specialty)',
	},
	status: {
		type: 'token',
		fhirtype: 'token',
		xpath: 'DocumentReference.status',
		definition: 'http://hl7.org/fhir/SearchParameter/DocumentReference-status',
		description: 'current | superseded | entered-in-error',
	},
	subject: {
		type: 'reference',
		fhirtype: 'reference',
		xpath: 'DocumentReference.subject',
		definition: 'http://hl7.org/fhir/SearchParameter/DocumentReference-subject',
		description: 'Who/what is the subject of the document',
	},
};
