/**
 * @name exports
 * @summary DocumentReferenceContext Class
 */
module.exports = class DocumentReferenceContext {
	constructor(opts) {
		// Create an object to store all props
		Object.defineProperty(this, '__data', { value: {} });

		// Define getters and setters as enumerable

		Object.defineProperty(this, '_id', {
			enumerable: true,
			get: () => this.__data._id,
			set: value => {
				if (value === undefined || value === null) {
					return;
				}

				let Element = require('./element.js');
				this.__data._id = new Element(value);
			},
		});

		Object.defineProperty(this, 'id', {
			enumerable: true,
			get: () => this.__data.id,
			set: value => {
				if (value === undefined || value === null) {
					return;
				}

				this.__data.id = value;
			},
		});

		Object.defineProperty(this, 'extension', {
			enumerable: true,
			get: () => this.__data.extension,
			set: value => {
				if (value === undefined || value === null) {
					return;
				}

				let Extension = require('./extension.js');
				this.__data.extension = Array.isArray(value) ? value.map(v => new Extension(v)) : [new Extension(value)];
			},
		});

		Object.defineProperty(this, 'modifierExtension', {
			enumerable: true,
			get: () => this.__data.modifierExtension,
			set: value => {
				if (value === undefined || value === null) {
					return;
				}

				let Extension = require('./extension.js');
				this.__data.modifierExtension = Array.isArray(value)
					? value.map(v => new Extension(v))
					: [new Extension(value)];
			},
		});

		Object.defineProperty(this, 'encounter', {
			enumerable: true,
			get: () => this.__data.encounter,
			set: value => {
				if (value === undefined || value === null) {
					return;
				}

				let Reference = require('./reference.js');
				this.__data.encounter = new Reference(value);
			},
		});
		// valueSetReference: http://hl7.org/fhir/ValueSet/v3-ActCode
		Object.defineProperty(this, 'event', {
			enumerable: true,
			get: () => this.__data.event,
			set: value => {
				if (value === undefined || value === null) {
					return;
				}

				let CodeableConcept = require('./codeableconcept.js');
				this.__data.event = Array.isArray(value)
					? value.map(v => new CodeableConcept(v))
					: [new CodeableConcept(value)];
			},
		});

		Object.defineProperty(this, 'period', {
			enumerable: true,
			get: () => this.__data.period,
			set: value => {
				if (value === undefined || value === null) {
					return;
				}

				let Period = require('./period.js');
				this.__data.period = new Period(value);
			},
		});
		// valueSetReference: http://hl7.org/fhir/ValueSet/c80-facilitycodes
		Object.defineProperty(this, 'facilityType', {
			enumerable: true,
			get: () => this.__data.facilityType,
			set: value => {
				if (value === undefined || value === null) {
					return;
				}

				let CodeableConcept = require('./codeableconcept.js');
				this.__data.facilityType = new CodeableConcept(value);
			},
		});
		// valueSetReference: http://hl7.org/fhir/ValueSet/c80-practice-codes
		Object.defineProperty(this, 'practiceSetting', {
			enumerable: true,
			get: () => this.__data.practiceSetting,
			set: value => {
				if (value === undefined || value === null) {
					return;
				}

				let CodeableConcept = require('./codeableconcept.js');
				this.__data.practiceSetting = new CodeableConcept(value);
			},
		});

		Object.defineProperty(this, 'sourcePatientInfo', {
			enumerable: true,
			get: () => this.__data.sourcePatientInfo,
			set: value => {
				if (value === undefined || value === null) {
					return;
				}

				let Reference = require('./reference.js');
				this.__data.sourcePatientInfo = new Reference(value);
			},
		});

		Object.defineProperty(this, 'related', {
			enumerable: true,
			get: () => this.__data.related,
			set: value => {
				if (value === undefined || value === null) {
					return;
				}

				let DocumentReferenceContextRelated = require('./documentreferencecontextrelated.js');
				this.__data.related = Array.isArray(value)
					? value.map(v => new DocumentReferenceContextRelated(v))
					: [new DocumentReferenceContextRelated(value)];
			},
		});

		// Merge in any defaults
		Object.assign(this, opts);

		// Define a default non-writable resourceType property
		Object.defineProperty(this, 'resourceType', {
			value: 'DocumentReferenceContext',
			enumerable: true,
			writable: false,
		});
	}

	static get resourceType() {
		return 'DocumentReferenceContext';
	}

	toJSON() {
		return {
			_id: this._id && this._id.toJSON(),
			id: this.id,
			extension: this.extension && this.extension.map(v => v.toJSON()),
			modifierExtension: this.modifierExtension && this.modifierExtension.map(v => v.toJSON()),
			encounter: this.encounter && this.encounter.toJSON(),
			event: this.event && this.event.map(v => v.toJSON()),
			period: this.period && this.period.toJSON(),
			facilityType: this.facilityType && this.facilityType.toJSON(),
			practiceSetting: this.practiceSetting && this.practiceSetting.toJSON(),
			sourcePatientInfo: this.sourcePatientInfo && this.sourcePatientInfo.toJSON(),
			related: this.related && this.related.map(v => v.toJSON()),
		};
	}
};
